@@ -1,5 +1,7 @@
 from io import BytesIO
 
+from pathlib import Path
+
 from ..core import ExternalCommandTask
 from ..io import lazy_read
 from ..utils import write_to_tmp_dir
@@ -96,13 +98,16 @@ class lessc(ExternalCommandTask):
     def process_via_tmp_dir(self, inputs):
         tmp_dir, paths = write_to_tmp_dir(inputs)
 
-        cmd = ['lessc']
+        base_cmd = ['lessc']
         if self.line_numbers:
-            cmd += ['--line-numbers=' + self.line_numbers]
-        cmd += [str(f) for f in self.files]
-        cmd += ['iron_output.css']
+            base_cmd += ['--line-numbers=' + self.line_numbers]
 
-        self.run_external(cmd, cwd=tmp_dir)
+        for f in self.files:
+            path = Path(f)
+            output_path = Path(f).with_suffix('.css')
+
+            self.run_external(base_cmd + [str(f), str(output_path)],
+                              cwd=tmp_dir)
 
         for t, c, m in walk(tmp_dir):
             if t not in paths:  # filter out any input files, returning only the new files
