@@ -2,6 +2,14 @@ from pathlib import Path
 
 from ..core import Task
 
+class directory(Task):
+    def __init__(self, dirname):
+        self.dirname = Path(dirname)
+
+    def process(self, inputs):
+        for t, c, m in inputs:
+            yield self.dirname / t, c, m
+
 
 class rename_replace(Task):
     def __init__(self, substring, replacement):
